@@ -15,10 +15,14 @@ from .projects import Projects
 from .departments import Departments
 from .charge_card_accounts import ChargeCardAccounts
 from .charge_card_transactions import ChargeCardTransactions
+from .contract_lines import ContractLines
+from .contracts import Contracts
 from .customers import Customers
 from .items import Items
 from .ap_payments import APPayments
 from .ar_invoices import ARInvoices
+from .ar_invoice_items import ARInvoiceItems
+from .ar_payments import ARPayments
 from .reimbursements import Reimbursements
 from .checking_accounts import CheckingAccounts
 from .savings_accounts import SavingsAccounts
@@ -35,10 +39,16 @@ from .revenue_recognition_schedules import RevRecSchedules
 from .revenue_recognition_schedule_entries import RevRecScheduleEntries
 from .cost_types import CostTypes
 from .order_entry_transactions import OrderEntryTransactions
+from .allocation_entry import AllocationEntry
+from .allocations import Allocations
+from .ar_aging import ARAging
+from .inventory_control_price_list_entries import InventoryControlPriceListEntries
 
 __all__ = [
     'ApiBase',
     'Contacts',
+    'Contracts',
+    'ContractLines',
     'Locations',
     'Employees',
     'Accounts',
@@ -54,7 +64,10 @@ __all__ = [
     'Customers',
     'Items',
     'APPayments',
+    'AllocationEntry',
     'ARInvoices',
+    'ARInvoiceItems',
+    'ARPayments',
     'Reimbursements',
     'CheckingAccounts',
     'SavingsAccounts',
@@ -71,4 +84,7 @@ __all__ = [
     'RevRecScheduleEntries',
     'CostTypes',
     'OrderEntryTransactions',
+    'Allocations',
+    'ARAging',
+    'InventoryControlPriceListEntries'
 ]
