@@ -193,13 +193,11 @@ class ApiBase:
         raw_response = self.__post_request_for_raw_response(dict_body, api_url)
         try:
             parsed_xml = xmltodict.parse(raw_response.text, force_list={self.__dimension})
-            print(parsed_xml)
         except:
             #bad xml format from Sage Intacct fix
             raw_response = '<root>' + raw_response.text + '</root>'
             parsed_xml = xmltodict.parse(raw_response, force_list={self.__dimension})['root']
         parsed_response = json.loads(json.dumps(parsed_xml))
-        print(parsed_response)
 
         if raw_response.status_code == 200:
             response = parsed_response.get('response', {})
@@ -602,7 +600,7 @@ class ApiBase:
 
         if formatted_filter:
             data['query']['filter'] = formatted_filter
-        print(data)
+
         for offset in range(0, count, pagesize):
             data['query']['offset'] = offset
             paginated_data = self.format_and_send_request(data)['data']
